##############################################################################
#
#    Accounting periods, for Odoo
#    Copyright (C) 2018 XCG Consulting <http://odoo.consulting>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from odoo import fields
from odoo import models


class AccountMoveLine(models.Model):
    """Add a period & dates onto accounting entries (taken from the related
    account.move object).
    """

    _inherit = 'account.move.line'

    period_id = fields.Many2one(
        related=('move_id', 'period_id'),
        compute_sudo=True,
        comodel_name='account.period',
        string='Period',
        help='The period this accounting document is in.',
        ondelete='restrict',
        readonly=True,
        store=True,
    )

    transaction_date = fields.Date(
        related=('move_id', 'transaction_date'),
        compute_sudo=True,
        string='Transaction date',
        help=(
            'Invoicing date when provided; otherwise this is the accounting '
            'date.'
        ),
        readonly=True,
        store=True,
    )
